WCClient class

Constructors

WCClient({SessionRequest? onSessionRequest, SocketError? onFailure, SocketClose? onDisconnect, EthSign? onEthSign, EthTransaction? onEthSignTransaction, EthTransaction? onEthSendTransaction, WalletSwitchNetwork? onWalletSwitchNetwork, CustomRequest? onCustomRequest, dynamic onConnect()?})

Properties

chainId → int?
no setter
hashCode → int
The hash code for this object.
no setterinherited
isConnected → bool
no setter
onConnect → dynamic Function()?
final
onCustomRequest → CustomRequest?
final
onDisconnect → SocketClose?
final
onEthSendTransaction → EthTransaction?
final
onEthSign → EthSign?
final
onEthSignTransaction → EthTransaction?
final
onFailure → SocketError?
final
onSessionRequest → SessionRequest?
final
onWalletSwitchNetwork → WalletSwitchNetwork?
final
peerId → String?
no setter
peerMeta → WCPeerMeta?
no setter
remotePeerId → String?
no setter
remotePeerMeta → WCPeerMeta?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
session → WCSession?
no setter
sessionStore → WCSessionStore
no setter

Methods

approveRequest<T>({required int id, required T result}) → dynamic
approveSession({required List<String> accounts, int? chainId}) → dynamic
connectFromSessionStore(WCSessionStore sessionStore, {HttpClient? customHttpClient}) → Future<void>
connectNewSession({required WCSession session, required WCPeerMeta peerMeta, HttpClient? customHttpClient}) → Future<void>
disconnect() → dynamic
killSession() → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rejectRequest({required int id, String message = "Reject by the user"}) → dynamic
rejectSession({String message = "Session rejected"}) → dynamic
toString() → String
A string representation of this object.
inherited
updateSession({List<String>? accounts, int? chainId, bool approved = true}) → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited